##  Insights from Business Context Fact Sheet
  * Show applications mapped to business context (e.g., process) leveraging the application landscape report.
  * Map customer (fact sheet subtype) to business products using the landscape report.
  * Show applications mapped to business context and business capabilities via the matrix report.
